scipy.sparse.lil
================

.. automodule:: scipy.sparse.lil

   
   
   .. rubric:: Functions

   .. autosummary::
   
      bisect_left
      getdtype
      isscalarlike
      issequence
      isshape
      isspmatrix
      isspmatrix_lil
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      lil_matrix
      spmatrix
   
   

   
   
   